# pandoc-crossref

Stub that prevents name clash with [conda-forge/pandoc-crossref](https://github.com/conda-forge/pandoc-crossref-feedstock). For pandoc-crossref see [pypandoc-crossref](https://github.com/kiwi0fruit/pypandoc-crossref).
